@@ -1,8 +1,16 @@
 import os
 import abbrs
 
-PACKAGE_NAME = abbrs.current_path()
-RC_FILENAME = '{PACKAGE_NAME}.json'
+def current_path():
+	p = os.path.realpath(__file__)
+	p = os.path.split(p)[0]
+	p = os.path.split(p)[-1]
+	return p
+
+PACKAGE_NAME = current_path()
+RC_FILENAME = f'{PACKAGE_NAME}.json'
+
+print(RC_FILENAME)
 
 def make_dat(ls):
 	def is_mp4(x):
